# OCRAnalyses


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**var_schema** | [**EmbeddedModelSchema**](EmbeddedModelSchema.md) |  | [optional] 
**iterable** | [**List[OCRAnalysis]**](OCRAnalysis.md) |  | 

## Example

```python
from openapi_client.models.ocr_analyses import OCRAnalyses

# TODO update the JSON string below
json = "{}"
# create an instance of OCRAnalyses from a JSON string
ocr_analyses_instance = OCRAnalyses.from_json(json)
# print the JSON string representation of the object
print OCRAnalyses.to_json()

# convert the object into a dict
ocr_analyses_dict = ocr_analyses_instance.to_dict()
# create an instance of OCRAnalyses from a dict
ocr_analyses_form_dict = ocr_analyses.from_dict(ocr_analyses_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


